<?php
/*
Plugin Name: Recently Popular Widget
Description: The widget for the Recently Popular plugin.
Author: Eric Biven
Author URI: http://eric.biven.us/
Plugin URI: http://eric.biven.us/2008/12/03/recently-popular-wordpress-plugin/
Version: 0.4.7
*/

// Copyright (c) 2008 Eric Biven
// Released under the FreeBSD license:
// http://www.freebsd.org/copyright/freebsd-license.html

// This type of pathing is required for my development environment.
require_once(ABSPATH.'wp-content/plugins/recently-popular/include.php');

class RecentlyPopularWidget {

    var $plugin_folder = '';
    var $default_options = array(
        'title' => 'Recently Popular',
        'interval_length' => 1,
        'interval_type' => 'WEEK',
        'limit' => 10,
        'user_type' => RP_USER_TYPE_ANONYMOUS,
        'post_type' => RP_POST_TYPE_ALL,
        'output_format' => '<a href="%post_url%">%post_title%</a>',
        'enable_categories' => 0,
        'categories' => ''
    );

    function RecentlyPopularWidget() {
        $this->plugin_folder = get_option('home').'/'.PLUGINDIR.'/recently_popular/';
    }

    function init() {
        if (!$options = get_option('widget_recently_popular')) {
            $options = array();
        }

        $widget_ops = array('classname' => 'widget_recently_popular', 'description' => 'Shows recently popular posts');
        $control_ops = array('id_base' => 'recently-popular', 'width' => '400');
        $name = 'Recently Popular';

        $registered = false;
        foreach (array_keys($options) as $o) {
            if (!isset($options[$o]['title'])) {
                continue;
            }

            $id = "recently-popular-$o";
            $registered = true;
            wp_register_sidebar_widget($id, $name, array(&$this, 'widget'), $widget_ops, array( 'number' => $o ) );
            wp_register_widget_control($id, $name, array(&$this, 'control'), $control_ops, array( 'number' => $o ) );
        }
        if (!$registered) {
            wp_register_sidebar_widget('recently-popular-1', $name, array(&$this, 'widget'), $widget_ops, array( 'number' => -1 ) );
            wp_register_widget_control('recently-popular-1', $name, array(&$this, 'control'), $control_ops, array( 'number' => -1 ) );
        }
    }

    function widget($args, $widget_args = 1) {
        extract($args);
        if (is_numeric($widget_args)) {
          $widget_args = array('number' => $widget_args);
        }
        $widget_args = wp_parse_args($widget_args, array('number' => -1));
        extract($widget_args, EXTR_SKIP);
        $options_all = get_option('widget_recently_popular');
        if (!isset($options_all[$number])) {
          return;
        }

        $options = $options_all[$number];

        // Fix up title
        $title = htmlspecialchars(stripslashes($options['title']));

        // Since output_format is new we need to ensure that the old default
        // value is used when no value is present.
        if ($options['output_format'] == "" || $options['output_format'] == null) {
            $options['output_format'] = '<a href="%post_url%">%post_title%</a>';
        }

        // If category filtering isn't enabled then don't feed the list to the
        // filter.
        if ($options['enable_categories'] != '1') {
            $options['categories'] = '';
        }

        echo "$before_widget\n$before_title$title$after_title\n";
        echo '  <ul>'."\n";
        get_recently_popular($options['interval_length'],
                             $options['interval_type'],
                             $options['limit'],
                             $options['user_type'],
                             $options['post_type'],
                             stripslashes($options['output_format']),
                             $options['categories']
                             );
        echo '  </ul>'."\n";
        echo $after_widget;
    }

    function control($widget_args = 1) {
        global $wp_registered_widgets, $wpdb;
        static $updated = false;

        if (is_numeric($widget_args)) {
            $widget_args = array('number' => $widget_args);
        }
        $widget_args = wp_parse_args($widget_args, array('number' => -1));
        extract($widget_args, EXTR_SKIP);
        $options_all = get_option('widget_recently_popular');
        if (!is_array($options_all)) {
            $options_all = array();
        }
        if (!$updated && !empty($_POST['sidebar'])) {
            $sidebar = (string)$_POST['sidebar'];

            $sidebars_widgets = wp_get_sidebars_widgets();
            if (isset($sidebars_widgets[$sidebar])) {
                $this_sidebar =& $sidebars_widgets[$sidebar];
            }
            else {
                $this_sidebar = array();
            }

            foreach ($this_sidebar as $_widget_id) {
                if ('widget_recently_popular' == $wp_registered_widgets[$_widget_id]['callback'] && isset($wp_registered_widgets[$_widget_id]['params'][0]['number'])) {
                    $widget_number = $wp_registered_widgets[$_widget_id]['params'][0]['number'];
                    if (!in_array("recently-popular-$widget_number", $_POST['widget-id']))
                        unset($options_all[$widget_number]);
                }
            }
            foreach ((array)$_POST['widget_recently_popular'] as $widget_number => $posted) {
                if (!isset($posted['title']) && isset($options_all[$widget_number])) {
                    continue;
                }

                $options = array();

                $options['title'] = $posted['title'];
                $options['interval_length'] = intval($posted['interval_length']);
                $options['interval_type'] = $posted['interval_type'];
                $options['limit'] = intval($posted['limit']);
                $options['user_type'] = intval($posted['user_type']);
                $options['post_type'] = intval($posted['post_type']);
                $options['output_format'] = $posted['output_format'];
                $options['enable_categories'] = ($posted['enable_categories'] == '1') ? '1' : '0';
                $options['categories'] = '';
                foreach ($posted['categories'] as $category) {
                    $options['categories'] .= "'$category',";
                }
                $options['categories'] = rtrim($options['categories'], ',');

                $options_all[$widget_number] = $options;
            }
            update_option('widget_recently_popular', $options_all);
            $updated = true;
        }

        if (-1 == $number) {
            $number = '%i%';
            $values = $this->default_options;
        }
        else {
            $values = $options_all[$number];
        }

        ?>

        <p><label for="widget_recently_popular-<?php echo $number;?>-title">Title:</label><br />
        <input id="widget_recently_popular-<?php echo $number;?>-title" name="widget_recently_popular[<?php echo $number;?>][title]" type="text" class="widefat" value="<?php echo $values['title']; ?>" /></p>

        <p><label for="widget_recently_popular-<?php echo $number;?>-interval-length">Count views no older than:</label><br />
        <input id="widget_recently_popular-<?php echo $number;?>-interval-length" name="widget_recently_popular[<?php echo $number;?>][interval_length]" type="text" value="<?php echo $values['interval_length']; ?>" size="3" />
        <select id="widget_recently_popular-<?php echo $number;?>-interval-type" name="widget_recently_popular[<?php echo $number;?>][interval_type]" size="1" />
          <option value="HOUR" <?php selected('HOUR', $values['interval_type']); ?>>Hour(s)</option>
          <option value="DAY" <?php selected('DAY', $values['interval_type']); ?>>Day(s)</option>
          <option value="WEEK" <?php selected('WEEK', $values['interval_type']); ?>>Week(s)</option>
          <option value="MONTH" <?php selected('MONTH', $values['interval_type']); ?>>Month(s)</option>
        </select></p>

        <p><label for="widget_recently_popular-<?php echo $number;?>-limit">Limit to no more than:</label><br />
        <input id="widget_recently_popular-<?php echo $number;?>-limit" name="widget_recently_popular[<?php echo $number;?>][limit]" type="text" value="<?php echo $values['limit']; ?>" size="3" /> posts</p>

        <p><label for="widget_recently_popular-<?php echo $number;?>-user-type">Count views by:</label><br />
        <select id="widget_recently_popular-<?php echo $number;?>-user-type" name="widget_recently_popular[<?php echo $number;?>][user_type]" size="1" />
          <option value="0" <?php selected('0', $values['user_type']); ?>>Anonymous &amp; Registered Users</option>
          <option value="1" <?php selected('1', $values['user_type']); ?>>Anonymous Users Only</option>
          <option value="2" <?php selected('2', $values['user_type']); ?>>Registered Users Only</option>
        </select></p>

        <p><label for="widget_recently_popular-<?php echo $number;?>-post-type">Count views of:</label><br />
        <select id="widget_recently_popular-<?php echo $number;?>-post-type" name="widget_recently_popular[<?php echo $number;?>][post_type]" size="1" />
          <option value="0" <?php selected('0', $values['post_type']); ?>>Pages &amp; Posts</option>
          <option value="1" <?php selected('1', $values['post_type']); ?>>Pages Only</option>
          <option value="2" <?php selected('2', $values['post_type']); ?>>Posts Only</option>
        </select></p>

        <a href="#" onclick="jQuery('#widget_recently_popular-<?php echo $number;?>-formatting').toggle();return false;">Show/hide formatting options</a><br/>
        <div style="display:none;" id="widget_recently_popular-<?php echo $number;?>-formatting">
            <p><label for="widget_recently_popular-<?php echo $number;?>-output-format">Format each result as:</label><br />
            <input id="widget_recently_popular-<?php echo $number;?>-output-format" name="widget_recently_popular[<?php echo $number;?>][output_format]" type="text" class="widefat" value="<?php echo stripslashes(htmlentities($values['output_format'])); ?>" />
            <br/>or choose a format below by clicking it:<br/>
            <span style="cursor:pointer;" onclick="document.getElementById('widget_recently_popular-<?php echo $number;?>-output-format').value='<a href=&quot;%post_url%&quot;>%post_title%</a>';"><u>Post Name</u></span><br/>
            <span style="cursor:pointer;" onclick="document.getElementById('widget_recently_popular-<?php echo $number;?>-output-format').value='<a href=&quot;%post_url%&quot;>%post_title% (%hits%)</a>';"><u>Post Name (Hits)</u></span><br/>
            <span style="cursor:pointer;" onclick="document.getElementById('widget_recently_popular-<?php echo $number;?>-output-format').value='<a href=&quot;%post_url%&quot;>%post_title%</a> by %display_name%';"><u>Post Name</u> by Author Name</span><br/>
            <div style="background-color:#f9f9f9;border:1px solid #000000;padding:3px;" id="widget_recently_popular-<?php echo $number;?>-tag-help">
                Available tags:<br/>
                <em>%post_url%</em> - the post's permalink<br/>
                <em>%post_title%</em> - the post's title<br/>
                <em>%hits%</em> - the number of qualifying views<br/>
                <em>%display_name%</em> - the post's author
            </div>
        </div>

        <br/>
        <a href="#" onclick="jQuery('#widget_recently_popular-<?php echo $number;?>-categories').toggle();return false;">Show/hide category options</a><br/>
        <div style="display:none;padding-bottom:10px;" id="widget_recently_popular-<?php echo $number;?>-categories">
            <p><em>*Note: Enabling category filtering will eliminate all posts with no category.  If pages are selected in 'Count views of' above then all pages will display since they can't have a category.</em></p>
            <p>
                <input type="checkbox" id="widget_recently_popular-<?php echo $number;?>-enable-categories" name="widget_recently_popular[<?php echo $number;?>][enable_categories]" <?php if ($values['enable_categories'] == '1') { echo 'checked="true"'; } ?> value="1" />
                &nbsp;<label for="widget_recently_popular-<?php echo $number;?>-enable-categories">Enable category filtering</label>
            </p>
            <p>
                <label for="widget_recently_popular-<?php echo $number;?>-categories">Choose only posts in these categories:</label><br />
                <select id="widget_recently_popular-<?php echo $number;?>-categories" name="widget_recently_popular[<?php echo $number;?>][categories][]" class="widefat" style="height:100px;width:92%;" multiple="true" />
                    <?php
                        $sql = "SELECT t.`name`
                                FROM $wpdb->terms AS t
                                LEFT JOIN $wpdb->term_taxonomy AS tt ON t.`term_id` = tt.`term_id`
                                WHERE tt.`taxonomy` = 'category'
                                ORDER BY t.`name` DESC
                        ";

                        $categories = $wpdb->get_results($sql);
                        foreach ($categories as $category) {
                            $name = $category->name;
                            $selected = '';
                            if (strpos($values['categories'], "'$name'") !== false) {
                                $selected = ' selected="selected"';
                            }
                            echo ("<option value=\"$name\"$selected>$name</option>");
                        }
                    ?>
                </select>
            </p>
        </div>
        </p>
        <p>&nbsp;</p>
        <?php
    }
}

$rpw = new RecentlyPopularWidget();
add_action('widgets_init', array($rpw, 'init'));

?>
